==> QupZilla-2.1.2.tar.xz: QupZilla-2.1.2/src/plugins/TabManager/translations/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Tabbladbeheerder-instellingen</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Selecteer het weergavetype:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Zijpaneel</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Noot:&lt;/span&gt; Het &amp;quot;Venster&amp;quot;-type is aanbevolen voor het beheren van vele vensters en/of tabbladen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Gebruik de Tabbladbeheerder-plug-in als vervanging van de algemene tabbladbalk.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Tabbladbeheerder</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Lokaal bestandssysteem:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation>[FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Groeperen op</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domeinnaam</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Host</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Naast elkaar weergeven</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Aangevinkte tabbladen loskoppelen</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Aangevinkte tabbladen toevoegen aan blad&amp;wijzers</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>Aangevinkte tabbladen &amp;sluiten</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Kies een map voor de bladwijzers:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Geselecteerde tabbladen aan bladwijzers toevoegen</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Venster %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation>Dubbelklik om om te schakelen</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Tabbladbeheerder</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Tabbladbeheerder weergeven</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.4.tar.xz: QupZilla-2.2.4/src/plugins/TabManager/translations/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Tabbladbeheerder-instellingen</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Selecteer het weergavetype:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Zijpaneel</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Noot:&lt;/span&gt; Het &amp;quot;Venster&amp;quot;-type is aanbevolen voor het beheren van vele vensters en/of tabbladen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Gebruik de Tabbladbeheerder-plug-in als vervanging van de algemene tabbladbalk.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Tabbladbeheerder</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Lokaal bestandssysteem:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation>[FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Groeperen op</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domeinnaam</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Host</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Naast elkaar weergeven</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Aangevinkte tabbladen loskoppelen</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Aangevinkte tabbladen toevoegen aan blad&amp;wijzers</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>Aangevinkte tabbladen &amp;sluiten</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Kies een bladwijzermap:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Geselecteerde tabbladen toevoegen aan bladwijzers</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Venster %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation>Dubbelklik om om te schakelen</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Tabbladbeheerder</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Tabbladbeheerder weergeven</translation>
    </message>
</context>
</TS>
